==> dokuwiki_0.0.20080505.orig.tar.gz: dokuwiki-2008-05-05/inc/lang/ar/lang.php <==
<?php
/**
 * Arabic language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author Mostafa Hussein <mostafa@gmail.com>
 */
$lang['encoding']              = 'utf-8';
$lang['direction']             = 'rtl';
$lang['doublequoteopening']    = '“';
$lang['doublequoteclosing']    = '”';
$lang['singlequoteopening']    = '‘';
$lang['singlequoteclosing']    = '’';
$lang['apostrophe']            = '؛';
$lang['btn_edit']              = 'تحرير هذه الصفحة';
$lang['btn_source']            = 'عرض مصدر الصفحة';
$lang['btn_show']              = 'عرض الصفحة';
$lang['btn_create']            = 'إنشاء هذه الصفحة';
$lang['btn_search']            = 'بحث';
$lang['btn_save']              = 'حفظ';
$lang['btn_preview']           = 'استعراض';
$lang['btn_top']               = 'لأعلى';
$lang['btn_newer']             = '<< أحدث';
$lang['btn_older']             = 'أقدم >>';
$lang['btn_revs']              = 'نسخ قديمة';
$lang['btn_recent']            = 'أحدث التعديلات';
$lang['btn_upload']            = 'تحميل';
$lang['btn_cancel']            = 'إلغاء';
$lang['btn_index']             = 'فهرس';
$lang['btn_secedit']           = 'تحرير';
$lang['btn_login']             = 'دخول';
$lang['btn_logout']            = 'خروج';
$lang['btn_admin']             = 'المدير';
$lang['btn_update']            = 'تحديث';
$lang['btn_delete']            = 'حذف';
$lang['btn_back']              = 'رجوع';
$lang['btn_backlink']          = 'ارتباطات';
$lang['btn_backtomedia']       = 'رجوع إلى اختيار ملف الوسائط';
$lang['btn_subscribe']         = 'اشترك في التعديلات';
$lang['btn_unsubscribe']       = 'إلغاء الاشتراك في التعديلات';
$lang['btn_profile']           = 'تحديث الملف الشخصي';
$lang['btn_reset']             = 'تفريغ';
$lang['btn_resendpwd']         = 'إرسال كلمة مرور جديدة';
$lang['btn_draft']             = 'تحرير المسوّدة';
$lang['btn_recover']           = 'استعادة المسوّدة';
$lang['btn_draftdel']          = 'حذف المسوّدة';
$lang['loggedinas']            = 'دخول باسم';
$lang['user']                  = 'اسم المشترك';
$lang['pass']                  = 'كلمة المرور';
$lang['newpass']               = 'كلمة مرور جديدة';
$lang['oldpass']               = 'تأكيد كلمة المرور الحالية';
$lang['passchk']               = 'مرة أخرى';
$lang['remember']              = 'تذكرني';
$lang['fullname']              = 'الاسم الكامل';
$lang['email']                 = 'البريد الإلكتروني';
$lang['register']              = 'تسجيل';
$lang['profile']               = 'الملف الشخصي';
$lang['badlogin']              = 'عذرا، اسم المشترك أو كلمة المرور غير صحيحة';
$lang['minoredit']             = 'تعديلات طفيفة';
$lang['draftdate']             = 'تشغيل حفظ المسوّدة آلياً';
$lang['regmissing']            = 'عذرا، يجب ملء جميع الخانات';
$lang['reguexists']            = 'عذرا، يوجد مشترك بنفس الاسم';
$lang['regsuccess']            = 'تم تسجيل المشترك و أرسلت كلمة المرور عبر البريد الإلكتروني';
$lang['regsuccess2']           = 'تم إنشاء المشترك';
$lang['regmailfail']           = 'حدث خطأ فى إرسال رسالة كلمة المرور. يرجى مراسلة المدير';
$lang['regbadmail']            = 'البريد الإلكتروني المعطى غير صحيح، إن كنت تظن الخطأ من الموقع راسل المدير';
$lang['regbadpass']            = 'كلمتى المرور غير متطابقتين، حاول مرة أخرى';
$lang['regpwmail']             = 'كلمة مرورك إلى دوكي ويكي';
$lang['reghere']               = 'لست مشتركاً؟ تفضل اشترك';
$lang['profna']                = 'هذه الويكي لا تدعم تعديل الملف الشخصي';
$lang['profnochange']          = 'لا تغييرات، لا شيء مطلوب عمله';
$lang['profnoempty']           = 'ليس مسموحاً ترك الاسم أو البريد الإلكتروني فارغاً';
$lang['profchanged']           = 'تم تحديث الملف الشخصي بنجاح';
$lang['pwdforget']             = 'نسيت كلمة المرور؟ احصل على واحدة جديدة';
$lang['resendna']              = 'هذه الويكي لا تدعم إعادة إرسال كلمة المرور';
$lang['resendpwd']             = 'إرسال كلمة المرور إلى';
$lang['resendpwdmissing']      = 'عذراّ، يجب أن تملأ جميع الخانات';
$lang['resendpwdnouser']       = 'عذراً، لدينا هذا المشترك في قاعدة بياناتنا';
$lang['resendpwdbadauth']      = 'عذراً، رمز التفعيل هذا غير صحيح. نأكد أنك استخدمت كامل وصلة التأكيد';
$lang['resendpwdconfirm']      = 'تم إرسال وصلة تأكيد إلى بريدك الإلكتروني';
$lang['resendpwdsuccess']      = 'كلمة مرورك الجديدة تم إرسالها عبر البريد الإلكتروني';
$lang['txt_upload']            = 'اختر ملفاً للتحميل';
$lang['txt_filename']          = 'تحميل باسم - اختياري';
$lang['txt_overwrt']           = 'الكتابة على ملف موجود بنفس الاسم مسموحة';
$lang['lockedby']              = 'حالياً مقفول بواسطة';
$lang['lockexpire']            = 'سينتهي القفل في';
$lang['willexpire']            = 'سينتهي قفل تحرير هذه الصفحه خلال دقيقة. لتجنب التعارض استخدم زر استعراض لبدأ القفل من جديد';
$lang['notsavedyet']           = 'التعديلات التي لم تحفظ ستفقد. أموافق؟';
$lang['rssfailed']             = 'خطأ ما حدث أثناء جلب ملف التغذية:';
$lang['nothingfound']          = 'لا يوجد شيء';
$lang['mediaselect']           = 'ملفات الوسائط المتعددة';
$lang['fileupload']            = 'تحميل ملف وسائط متعددة';
$lang['uploadsucc']            = 'تم التحميل بنجاح';
$lang['uploadfail']            = 'فشل التحميل، قد يكون الخطأ فى التراخيص؟';
$lang['uploadwrong']           = 'التحميل ممنوع، نوع الملف مرفوض!';
$lang['uploadexist']           = 'الملف موجود أصلاً. لم يحدث شيء';
$lang['uploadbadcontent']      = 'المحتوى المحمّل لم يتطابق مع نوع الملف %s';
$lang['uploadspam']            = 'التحميل محجوب بواسطة القائمة السوداء لبرنامج تقفي التطفل';
$lang['uploadxss']             = 'التحميل محجوب لمنع المحتويات الخبيثة';
$lang['deletesucc']            = 'تم حذف الملف "%s"';
$lang['deletefail']            = 'لا يمكن حذف "%s"، تأكد من تراخيصك';
$lang['mediainuse']            = 'لم يحذف الملف "%s"، مازال موجوداً';
$lang['namespaces']            = 'فضاء التسمية';
$lang['mediafiles']            = 'ملفات موجودة في';
$lang['js']['keepopen']        = 'أبقي النافذة مفتوحة أثناء الاختيار';
$lang['js']['hidedetails']     = 'إخفاء التفاصيل';
$lang['mediausage']            = 'استخدم هذه الصياغة للدلالة على هذا الملف:';
$lang['mediaview']             = 'عرض الملف الأصلي';
$lang['mediaroot']             = 'الجذر';
$lang['mediaupload']           = 'تحميل ملف إلى فضاء التسمية هنا. لإنشاء فضاءات تسمية فرعية، أضفها إلى بداية خانة تحميل باسم وافصل بينها باستخدام الفواصل';
$lang['mediaextchange']        = 'تم تغيير نوع الملف من .%s إلى .%s!';
$lang['reference']             = 'مراجع لـ';
$lang['ref_inuse']             = 'لا يمكن حذف الملف، لأنه مستخدم من قبل الصفحات التالية:';
$lang['ref_hidden']            = 'بعض المراجع لصفاحات لا تملك ترخيص برؤيتها';
$lang['hits']                  = 'زوار';
$lang['quickhits']             = 'صفحات بهذا الاسم';
$lang['toc']                   = 'جدول المحتويات';
$lang['current']               = 'حالي';
$lang['yours']                 = 'نسختك';
$lang['diff']                  = 'مقارنة بالنسخة الحالية';
$lang['diff2']                 = 'مقارنة بين النسخ المختارة';
$lang['line']                  = 'سطر';
$lang['breadcrumb']            = 'أثر';
$lang['youarehere']            = 'أنت هنا';
$lang['lastmod']               = 'آخر تعديل';
$lang['by']                    = 'بواسطة';
$lang['deleted']               = 'تم حذف';
$lang['created']               = 'تم إنشاء';
$lang['restored']              = 'عودة لنسخة قديمة';
$lang['external_edit']         = 'تحرير خارجي';
$lang['summary']               = 'ملخص التحرير';
$lang['mail_newpage']          = 'إضافة صفحة:';
$lang['mail_changed']          = 'تعديل صفحة:';
$lang['mail_new_user']         = 'مشترك جديد';
$lang['mail_upload']           = 'تحميل ملف:';
$lang['nosmblinks']            = 'الروابط لمجلدات ويندوز المشاركة تعمل فقط مع متصفح مايكروسفت Internet Explorer.  ما زال بإمكانك قص و لصق الرابط.';
$lang['qb_alert']              = 'يرجى إدخال النص المراد صياغتة. سيتم إضافته فى نهاية المستند';
$lang['qb_bold']               = 'نص عريض';
$lang['qb_italic']             = 'نص مائل';
$lang['qb_underl']             = 'نص مسطر';
$lang['qb_code']               = 'نص برمجي';
$lang['qb_strike']             = 'نص مشطوب';
$lang['qb_h1']                 = 'عنوان مستوى أول';
$lang['qb_h2']                 = 'عنوان مستوى ثاني';
$lang['qb_h3']                 = 'عنوان مستوى ثالث';
$lang['qb_h4']                 = 'عنوان مستوى رابع';
$lang['qb_h5']                 = 'عنوان مستوى خامس';
$lang['qb_link']               = 'رابط داخلي';
$lang['qb_extlink']            = 'رابط خارجي';
$lang['qb_hr']                 = 'سطر أفقي';
$lang['qb_ol']                 = 'بند فى قائمة مرتبة';
$lang['qb_ul']                 = 'بند فى قائمة غير مرتبة';
$lang['qb_media']              = 'إضافة صور و ملفات أخرى';
$lang['qb_sig']                = 'أضف توقيعك';
$lang['qb_smileys']            = 'الابتسامات';
$lang['qb_chars']              = 'محارف خاصة';
$lang['del_confirm']           = 'هل حقاً تريد حذف البنود المختارة؟';
$lang['admin_register']        = 'إضافة مشترك جديد';
$lang['metaedit']              = 'تحرير البيانات الشمولية ';
$lang['metasaveerr']           = 'فشلت عملية كتابة البيانات الشمولية';
$lang['metasaveok']            = 'تم حفظ البيانت الشمولية';
$lang['img_backto']            = 'العودة إلى';
$lang['img_title']             = 'العنوان';
$lang['img_caption']           = 'تنويه الصورة';
$lang['img_date']              = 'التاريخ';
$lang['img_fname']             = 'اسم الملف';
$lang['img_fsize']             = 'الحجم';
$lang['img_artist']            = 'المصور';
$lang['img_copyr']             = 'حقوق النسخ';
$lang['img_format']            = 'صيغ رسومية';
$lang['img_camera']            = 'آلة التصوير';
$lang['img_keywords']          = 'كلمات مفتاحية';
$lang['subscribe_success']     = 'تم إضافة %s لقائمة الاشتراكات %s';
$lang['subscribe_error']       = 'حدث خطأ فى إضافة %s لقائمة الاشتراكات %s';
$lang['subscribe_noaddress']   = 'لا يوجد عنوان مرفق مع بيانات تسجيلك، لا يمكن إضافتك إلى قائمة الاشتراكات';
$lang['unsubscribe_success']   = 'تم حذف%s من قائمة الاشتراكات %s';
$lang['unsubscribe_error']     = 'حدث خطأ فى حذف %s من قائمة الاشتراكات %s';
$lang['authmodfailed']         = 'إعدادات تصريح فاسدة، يرجى مراسلة المدير.';
$lang['authtempfail']          = 'تصريح المشترك غير متوفر مؤقتاً، إن استمرت هذه الحالة يرجى مراسلة المدير';
$lang['i_chooselang']          = 'اختر لغتك';
$lang['i_installer']           = 'برنامج تنصيب دوكي ويكي';
$lang['i_wikiname']            = 'اسم الويكي';
$lang['i_enableacl']           = 'تفعيل ACL - مفضل';
$lang['i_superuser']           = 'مشرف';
$lang['i_problems']            = 'وجد برنامج التنصيب المشاكل التالية، لا يمكنك المتابعة قبل حلها.';
$lang['i_modified']            = 'لأسباب أمنية هذا البرنامج سيعمل فقط مع تنصيب دوكي ويكي جديد و غير معدّل.
يجب أن تعيد فك ضغط الملفات مرة أخرى من المكتبة المضغوطة، أو راجع <a href="http://wiki.splitbrain.org/wiki:install"> تعليمات تنصيب دوكي ويكي </a> ';
$lang['i_funcna']              = 'دالة PHP التالية غير متوفرة.
<code>%s</code>
قد يكون مزود خدمة الاستفادة قد حجبها لسبب ما.';
$lang['i_phpver']              = 'نسخة PHP التي لديك هي 
<code>%s</code>
وهي أقل من النسخة المطلوبة
<code>%s</code>
عليك تحديث نسخة PHP';
$lang['i_permfail']            = 'إن <code>%s</code> غير قابل للكتابة بواسطة دوكي ويكي، عليك تعديل إعدادات الصلاحيات لهذا المجلد!';
$lang['i_confexists']          = 'إن <code>%s</code> موجود أصلاً';
$lang['i_writeerr']            = 'لا يمكن إنشاء <code>%s</code>، عليك التأكد من صلاحيات الملف أو المجلد وإنشاء الملف يدوياً.';
$lang['i_badhash']             = 'الملف dokuwiki.php غير مصنف أو قد تم تعديله 
(hash=<code>%s</code>)';
$lang['i_badval']              = 'القيمة <code>%s</code> غير شرعية أو فارغة';
$lang['i_success']             = 'الإعدادات تمت بنجاح، يرجى حذف الملف install.php الآن.
ثم تابع إلى <a href="doku.php"> دوكي ويكي الجديدة</a>';
$lang['i_failure']             = 'بعض الأخطاء حدثت أثنا كتابة ملفات الإعدادات، عليك تعديلها يدوياً قبل أن تستطيع استخدام <a href="doku.php"> دوكي ويكي الجديدة</a>';
$lang['i_policy']              = 'تصريح ACL مبدئي';
$lang['i_pol0']                = 'ويكي مفتوحة؛ أي القراءة والكتابة والتحميل مسموحة للجميع';
$lang['i_pol1']                = 'ويكي عامة؛ أي القراءة للجميع ولكن الكتابة والتحميل للمشتركين المسجلين فقط';
$lang['i_pol2']                = 'ويكي مغلقة؛ أي القراءة والكتابة والتحميل للمشتركين المسجلين فقط';
$lang['i_retry']               = 'إعادة المحاولة';

==> dokuwiki_0.0.20090214b.orig.tar.gz: dokuwiki-2009-02-14/inc/lang/ar/lang.php <==
<?php
/**
 * Arabic language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author Mostafa Hussein <mostafa@gmail.com>
 */
$lang['encoding']              = 'utf-8';
$lang['direction']             = 'rtl';
$lang['doublequoteopening']    = '“';
$lang['doublequoteclosing']    = '”';
$lang['singlequoteopening']    = '‘';
$lang['singlequoteclosing']    = '’';
$lang['apostrophe']            = '؛';
$lang['btn_edit']              = 'تحرير هذه الصفحة';
$lang['btn_source']            = 'عرض مصدر الصفحة';
$lang['btn_show']              = 'عرض الصفحة';
$lang['btn_create']            = 'إنشاء هذه الصفحة';
$lang['btn_search']            = 'بحث';
$lang['btn_save']              = 'حفظ';
$lang['btn_preview']           = 'استعراض';
$lang['btn_top']               = 'لأعلى';
$lang['btn_newer']             = '<< أحدث';
$lang['btn_older']             = 'أقدم >>';
$lang['btn_revs']              = 'نسخ قديمة';
$lang['btn_recent']            = 'أحدث التعديلات';
$lang['btn_upload']            = 'تحميل';
$lang['btn_cancel']            = 'إلغاء';
$lang['btn_index']             = 'فهرس';
$lang['btn_secedit']           = 'تحرير';
$lang['btn_login']             = 'دخول';
$lang['btn_logout']            = 'خروج';
$lang['btn_admin']             = 'المدير';
$lang['btn_update']            = 'تحديث';
$lang['btn_delete']            = 'حذف';
$lang['btn_back']              = 'رجوع';
$lang['btn_backlink']          = 'ارتباطات';
$lang['btn_backtomedia']       = 'رجوع إلى اختيار ملف الوسائط';
$lang['btn_subscribe']         = 'اشترك في التعديلات';
$lang['btn_unsubscribe']       = 'إلغاء الاشتراك في التعديلات';
$lang['btn_profile']           = 'تحديث الملف الشخصي';
$lang['btn_reset']             = 'تفريغ';
$lang['btn_resendpwd']         = 'إرسال كلمة مرور جديدة';
$lang['btn_draft']             = 'تحرير المسوّدة';
$lang['btn_recover']           = 'استعادة المسوّدة';
$lang['btn_draftdel']          = 'حذف المسوّدة';
$lang['loggedinas']            = 'دخول باسم';
$lang['user']                  = 'اسم المشترك';
$lang['pass']                  = 'كلمة المرور';
$lang['newpass']               = 'كلمة مرور جديدة';
$lang['oldpass']               = 'تأكيد كلمة المرور الحالية';
$lang['passchk']               = 'مرة أخرى';
$lang['remember']              = 'تذكرني';
$lang['fullname']              = 'الاسم الكامل';
$lang['email']                 = 'البريد الإلكتروني';
$lang['register']              = 'تسجيل';
$lang['profile']               = 'الملف الشخصي';
$lang['badlogin']              = 'عذرا، اسم المشترك أو كلمة المرور غير صحيحة';
$lang['minoredit']             = 'تعديلات طفيفة';
$lang['draftdate']             = 'تشغيل حفظ المسوّدة آلياً';
$lang['regmissing']            = 'عذرا، يجب ملء جميع الخانات';
$lang['reguexists']            = 'عذرا، يوجد مشترك بنفس الاسم';
$lang['regsuccess']            = 'تم تسجيل المشترك و أرسلت كلمة المرور عبر البريد الإلكتروني';
$lang['regsuccess2']           = 'تم إنشاء المشترك';
$lang['regmailfail']           = 'حدث خطأ فى إرسال رسالة كلمة المرور. يرجى مراسلة المدير';
$lang['regbadmail']            = 'البريد الإلكتروني المعطى غير صحيح، إن كنت تظن الخطأ من الموقع راسل المدير';
$lang['regbadpass']            = 'كلمتى المرور غير متطابقتين، حاول مرة أخرى';
$lang['regpwmail']             = 'كلمة مرورك إلى دوكي ويكي';
$lang['reghere']               = 'لست مشتركاً؟ تفضل اشترك';
$lang['profna']                = 'هذه الويكي لا تدعم تعديل الملف الشخصي';
$lang['profnochange']          = 'لا تغييرات، لا شيء مطلوب عمله';
$lang['profnoempty']           = 'ليس مسموحاً ترك الاسم أو البريد الإلكتروني فارغاً';
$lang['profchanged']           = 'تم تحديث الملف الشخصي بنجاح';
$lang['pwdforget']             = 'نسيت كلمة المرور؟ احصل على واحدة جديدة';
$lang['resendna']              = 'هذه الويكي لا تدعم إعادة إرسال كلمة المرور';
$lang['resendpwd']             = 'إرسال كلمة المرور إلى';
$lang['resendpwdmissing']      = 'عذراّ، يجب أن تملأ جميع الخانات';
$lang['resendpwdnouser']       = 'عذراً، لدينا هذا المشترك في قاعدة بياناتنا';
$lang['resendpwdbadauth']      = 'عذراً، رمز التفعيل هذا غير صحيح. نأكد أنك استخدمت كامل وصلة التأكيد';
$lang['resendpwdconfirm']      = 'تم إرسال وصلة تأكيد إلى بريدك الإلكتروني';
$lang['resendpwdsuccess']      = 'كلمة مرورك الجديدة تم إرسالها عبر البريد الإلكتروني';
$lang['txt_upload']            = 'اختر ملفاً للتحميل';
$lang['txt_filename']          = 'تحميل باسم - اختياري';
$lang['txt_overwrt']           = 'الكتابة على ملف موجود بنفس الاسم مسموحة';
$lang['lockedby']              = 'حالياً مقفول بواسطة';
$lang['lockexpire']            = 'سينتهي القفل في';
$lang['willexpire']            = 'سينتهي قفل تحرير هذه الصفحه خلال دقيقة. لتجنب التعارض استخدم زر استعراض لبدأ القفل من جديد';
$lang['notsavedyet']           = 'التعديلات التي لم تحفظ ستفقد. أموافق؟';
$lang['rssfailed']             = 'خطأ ما حدث أثناء جلب ملف التغذية:';
$lang['nothingfound']          = 'لا يوجد شيء';
$lang['mediaselect']           = 'ملفات الوسائط المتعددة';
$lang['fileupload']            = 'تحميل ملف وسائط متعددة';
$lang['uploadsucc']            = 'تم التحميل بنجاح';
$lang['uploadfail']            = 'فشل التحميل، قد يكون الخطأ فى التراخيص؟';
$lang['uploadwrong']           = 'التحميل ممنوع، نوع الملف مرفوض!';
$lang['uploadexist']           = 'الملف موجود أصلاً. لم يحدث شيء';
$lang['uploadbadcontent']      = 'المحتوى المحمّل لم يتطابق مع نوع الملف %s';
$lang['uploadspam']            = 'التحميل محجوب بواسطة القائمة السوداء لبرنامج تقفي التطفل';
$lang['uploadxss']             = 'التحميل محجوب لمنع المحتويات الخبيثة';
$lang['deletesucc']            = 'تم حذف الملف "%s"';
$lang['deletefail']            = 'لا يمكن حذف "%s"، تأكد من تراخيصك';
$lang['mediainuse']            = 'لم يحذف الملف "%s"، مازال موجوداً';
$lang['namespaces']            = 'فضاء التسمية';
$lang['mediafiles']            = 'ملفات موجودة في';
$lang['js']['keepopen']        = 'أبقي النافذة مفتوحة أثناء الاختيار';
$lang['js']['hidedetails']     = 'إخفاء التفاصيل';
$lang['mediausage']            = 'استخدم هذه الصياغة للدلالة على هذا الملف:';
$lang['mediaview']             = 'عرض الملف الأصلي';
$lang['mediaroot']             = 'الجذر';
$lang['mediaupload']           = 'تحميل ملف إلى فضاء التسمية هنا. لإنشاء فضاءات تسمية فرعية، أضفها إلى بداية خانة تحميل باسم وافصل بينها باستخدام الفواصل';
$lang['mediaextchange']        = 'تم تغيير نوع الملف من .%s إلى .%s!';
$lang['reference']             = 'مراجع لـ';
$lang['ref_inuse']             = 'لا يمكن حذف الملف، لأنه مستخدم من قبل الصفحات التالية:';
$lang['ref_hidden']            = 'بعض المراجع لصفاحات لا تملك ترخيص برؤيتها';
$lang['hits']                  = 'زوار';
$lang['quickhits']             = 'صفحات بهذا الاسم';
$lang['toc']                   = 'جدول المحتويات';
$lang['current']               = 'حالي';
$lang['yours']                 = 'نسختك';
$lang['diff']                  = 'مقارنة بالنسخة الحالية';
$lang['diff2']                 = 'مقارنة بين النسخ المختارة';
$lang['line']                  = 'سطر';
$lang['breadcrumb']            = 'أثر';
$lang['youarehere']            = 'أنت هنا';
$lang['lastmod']               = 'آخر تعديل';
$lang['by']                    = 'بواسطة';
$lang['deleted']               = 'تم حذف';
$lang['created']               = 'تم إنشاء';
$lang['restored']              = 'عودة لنسخة قديمة';
$lang['external_edit']         = 'تحرير خارجي';
$lang['summary']               = 'ملخص التحرير';
$lang['mail_newpage']          = 'إضافة صفحة:';
$lang['mail_changed']          = 'تعديل صفحة:';
$lang['mail_new_user']         = 'مشترك جديد';
$lang['mail_upload']           = 'تحميل ملف:';
$lang['js']['nosmblinks']            = "الروابط لمجلدات ويندوز المشاركة تعمل فقط مع متصفح مايكروسفت Internet Explorer.  ما زال بإمكانك قص و لصق الرابط.";
$lang['qb_alert']              = 'يرجى إدخال النص المراد صياغتة. سيتم إضافته فى نهاية المستند';
$lang['qb_bold']               = 'نص عريض';
$lang['qb_italic']             = 'نص مائل';
$lang['qb_underl']             = 'نص مسطر';
$lang['qb_code']               = 'نص برمجي';
$lang['qb_strike']             = 'نص مشطوب';
$lang['qb_h1']                 = 'عنوان مستوى أول';
$lang['qb_h2']                 = 'عنوان مستوى ثاني';
$lang['qb_h3']                 = 'عنوان مستوى ثالث';
$lang['qb_h4']                 = 'عنوان مستوى رابع';
$lang['qb_h5']                 = 'عنوان مستوى خامس';
$lang['qb_link']               = 'رابط داخلي';
$lang['qb_extlink']            = 'رابط خارجي';
$lang['qb_hr']                 = 'سطر أفقي';
$lang['qb_ol']                 = 'بند فى قائمة مرتبة';
$lang['qb_ul']                 = 'بند فى قائمة غير مرتبة';
$lang['qb_media']              = 'إضافة صور و ملفات أخرى';
$lang['qb_sig']                = 'أضف توقيعك';
$lang['qb_smileys']            = 'الابتسامات';
$lang['qb_chars']              = 'محارف خاصة';
$lang['del_confirm']           = 'هل حقاً تريد حذف البنود المختارة؟';
$lang['admin_register']        = 'إضافة مشترك جديد';
$lang['metaedit']              = 'تحرير البيانات الشمولية ';
$lang['metasaveerr']           = 'فشلت عملية كتابة البيانات الشمولية';
$lang['metasaveok']            = 'تم حفظ البيانت الشمولية';
$lang['img_backto']            = 'العودة إلى';
$lang['img_title']             = 'العنوان';
$lang['img_caption']           = 'تنويه الصورة';
$lang['img_date']              = 'التاريخ';
$lang['img_fname']             = 'اسم الملف';
$lang['img_fsize']             = 'الحجم';
$lang['img_artist']            = 'المصور';
$lang['img_copyr']             = 'حقوق النسخ';
$lang['img_format']            = 'صيغ رسومية';
$lang['img_camera']            = 'آلة التصوير';
$lang['img_keywords']          = 'كلمات مفتاحية';
$lang['subscribe_success']     = 'تم إضافة %s لقائمة الاشتراكات %s';
$lang['subscribe_error']       = 'حدث خطأ فى إضافة %s لقائمة الاشتراكات %s';
$lang['subscribe_noaddress']   = 'لا يوجد عنوان مرفق مع بيانات تسجيلك، لا يمكن إضافتك إلى قائمة الاشتراكات';
$lang['unsubscribe_success']   = 'تم حذف%s من قائمة الاشتراكات %s';
$lang['unsubscribe_error']     = 'حدث خطأ فى حذف %s من قائمة الاشتراكات %s';
$lang['authmodfailed']         = 'إعدادات تصريح فاسدة، يرجى مراسلة المدير.';
$lang['authtempfail']          = 'تصريح المشترك غير متوفر مؤقتاً، إن استمرت هذه الحالة يرجى مراسلة المدير';
$lang['i_chooselang']          = 'اختر لغتك';
$lang['i_installer']           = 'برنامج تنصيب دوكي ويكي';
$lang['i_wikiname']            = 'اسم الويكي';
$lang['i_enableacl']           = 'تفعيل ACL - مفضل';
$lang['i_superuser']           = 'مشرف';
$lang['i_problems']            = 'وجد برنامج التنصيب المشاكل التالية، لا يمكنك المتابعة قبل حلها.';
$lang['i_modified']            = 'لأسباب أمنية هذا البرنامج سيعمل فقط مع تنصيب دوكي ويكي جديد و غير معدّل.
يجب أن تعيد فك ضغط الملفات مرة أخرى من المكتبة المضغوطة، أو راجع <a href="http://dokuwiki.org/install"> تعليمات تنصيب دوكي ويكي </a> ';
$lang['i_funcna']              = 'دالة PHP التالية غير متوفرة.
<code>%s</code>
قد يكون مزود خدمة الاستفادة قد حجبها لسبب ما.';
$lang['i_phpver']              = 'نسخة PHP التي لديك هي 
<code>%s</code>
وهي أقل من النسخة المطلوبة
<code>%s</code>
عليك تحديث نسخة PHP';
$lang['i_permfail']            = 'إن <code>%s</code> غير قابل للكتابة بواسطة دوكي ويكي، عليك تعديل إعدادات الصلاحيات لهذا المجلد!';
$lang['i_confexists']          = 'إن <code>%s</code> موجود أصلاً';
$lang['i_writeerr']            = 'لا يمكن إنشاء <code>%s</code>، عليك التأكد من صلاحيات الملف أو المجلد وإنشاء الملف يدوياً.';
$lang['i_badhash']             = 'الملف dokuwiki.php غير مصنف أو قد تم تعديله 
(hash=<code>%s</code>)';
$lang['i_badval']              = 'القيمة <code>%s</code> غير شرعية أو فارغة';
$lang['i_success']             = 'الإعدادات تمت بنجاح، يرجى حذف الملف install.php الآن.
ثم تابع إلى <a href="doku.php"> دوكي ويكي الجديدة</a>';
$lang['i_failure']             = 'بعض الأخطاء حدثت أثنا كتابة ملفات الإعدادات، عليك تعديلها يدوياً قبل أن تستطيع استخدام <a href="doku.php"> دوكي ويكي الجديدة</a>';
$lang['i_policy']              = 'تصريح ACL مبدئي';
$lang['i_pol0']                = 'ويكي مفتوحة؛ أي القراءة والكتابة والتحميل مسموحة للجميع';
$lang['i_pol1']                = 'ويكي عامة؛ أي القراءة للجميع ولكن الكتابة والتحميل للمشتركين المسجلين فقط';
$lang['i_pol2']                = 'ويكي مغلقة؛ أي القراءة والكتابة والتحميل للمشتركين المسجلين فقط';
$lang['i_retry']               = 'إعادة المحاولة';
